@@ -1,7 +1,7 @@
-/* gok-action.h
+/* gok-input.h
 *
-* Copyright 2002 Sun Microsystems, Inc.,
-* Copyright 2002 University Of Toronto
+* Copyright 2002-2005 Sun Microsystems, Inc.,
+* Copyright 2002-2005 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -47,21 +47,30 @@ struct _GokInput {
 #ifdef HAVE_XINPUT
         XDeviceInfo *info; 
         XDevice     *device;
-	GokInput    *next;
+        gboolean    open;
 #endif
 };
 
 extern int gok_input_types[N_INPUT_TYPES];
 
 GokInput * gok_input_find_by_name (char *name, gboolean extended_only); 
-gboolean   gok_input_init (GokInput *input, GdkFilterFunc filter_func); 
-gboolean   gok_input_open (GokInput *input);
+GokInput * gok_input_find_by_device_id (guint device_id, gboolean extended_only); 
+gboolean   gok_input_init (GdkFilterFunc filter_func); 
+void       gok_input_open_all (void);
+void       gok_input_close_others (void);
 GokInput * gok_input_get_current (void);
+void       gok_input_set_current (GokInput *input);
 GSList *   gok_input_get_device_list (void);
 gboolean   gok_input_set_extension_device_by_name (char *name);
 gchar *    gok_input_get_extension_device_name (void);
 void       gok_input_free (GokInput *input);
-
+#ifdef HAVE_XINPUT
+gboolean   gok_input_ext_devices_exist (void);
+void       gok_input_detach_corepointer (void);
+void       gok_input_mismatch_warn (XDeviceInfo *devinfo);
+GdkFilterReturn gok_input_extension_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data);
+void       gok_input_restore_corepointer (void);
+#endif
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
